@@ -16,7 +16,7 @@ class Posts:
         response = requests.post(endpointURL, json = payload)
         return response.json()
 
-    def getPostInfo(self, postHash, commentLimit = 20, fetchParents = False, commentOffset = 0, addGlobalFeedBool = False, readerPublicKey = "BC1YLianxEsskKYNyL959k6b6UPYtRXfZs4MF3GkbWofdoFQzZCkJRB",):
+    def getPostInfo(postHash, commentLimit = 20, fetchParents = False, commentOffset = 0, addGlobalFeedBool = False, readerPublicKey = "BC1YLianxEsskKYNyL959k6b6UPYtRXfZs4MF3GkbWofdoFQzZCkJRB"):
         payload = {"PostHashHex":"",
                 "ReaderPublicKeyBase58Check":readerPublicKey,
                 "FetchParents":fetchParents,
